"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DelayedChangesFieldPlugin = void 0;
var util_1 = require("../../../../util");
var DelayedChangesFieldPlugin = /** @class */ (function () {
    /**
     * @stable [14.10.2020]
     * @param component
     */
    function DelayedChangesFieldPlugin(component) {
        this.component = component;
        this.delayedTask = new util_1.DelayedTask(this.doDelay.bind(this), util_1.NvlUtils.nvl(component.props.delayTimeout, DelayedChangesFieldPlugin.DEFAULT_DELAY_TIMEOUT));
        component.onChange = util_1.sequence(component.onChange, this.onChange, this);
        component.onChangeManually = util_1.sequence(component.onChangeManually, this.onChangeManually, this);
        component.onKeyEnter = util_1.sequence(component.onKeyEnter, this.onKeyEnter, this);
    }
    /**
     * @stable [04.05.2018]
     */
    DelayedChangesFieldPlugin.prototype.componentWillUnmount = function () {
        this.delayedTask.stop();
    };
    /**
     * @stable [14.10.2020]
     * @param event
     * @private
     */
    DelayedChangesFieldPlugin.prototype.onKeyEnter = function (event) {
        util_1.EventUtils.cancelEvent(event);
        this.delayedTask.stop();
        this.doDelay();
    };
    /**
     * @stable [04.05.2018]
     * @param {IChangeEvent} event
     */
    DelayedChangesFieldPlugin.prototype.onChange = function (event) {
        this.onChangeManually(event.target.value);
    };
    /**
     * @stable [18.05.2018]
     */
    DelayedChangesFieldPlugin.prototype.onChangeManually = function (value) {
        this.currentValue = value;
        this.delayedTask.start();
    };
    /**
     * @stable [14.10.2020]
     * @private
     */
    DelayedChangesFieldPlugin.prototype.doDelay = function () {
        util_1.ConditionUtils.ifNotNilThanValue(this.component.props.onDelay, function (onDelay) { return onDelay(); });
    };
    DelayedChangesFieldPlugin.DEFAULT_DELAY_TIMEOUT = 1500;
    return DelayedChangesFieldPlugin;
}());
exports.DelayedChangesFieldPlugin = DelayedChangesFieldPlugin;
//# sourceMappingURL=delayed-changes-field.plugin.js.map