"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var definition_1 = require("../../definition");
var form_reducer_1 = require("./form.reducer");
var action_1 = require("../../action");
var TEST_SECTION = 'test';
describe('form.reducer', function () {
    describe(definition_1.FORM_RESET_ACTION_TYPE, function () {
        it('test1', function () {
            var reducedForm = form_reducer_1.formReducer({
                activeValue: 1,
                changes: { test1: 'test1' },
                defaultChanges: { initialValue: 1 },
                dirty: true,
                touched: true,
                valid: true,
            }, action_1.FormActionBuilder.buildResetPlainAction(TEST_SECTION));
            var result = {
                activeValue: 1,
                changes: {},
                defaultChanges: { initialValue: 1 },
                dirty: true,
                validateAfterReset: true,
            };
            expect(reducedForm).toEqual(result);
        });
        it('test2', function () {
            var reducedForm = form_reducer_1.formReducer({
                activeValue: 1,
                changes: { test1: 'test1' },
                defaultChanges: {},
                dirty: true,
                touched: true,
                valid: true,
            }, action_1.FormActionBuilder.buildResetPlainAction(TEST_SECTION));
            var result = {
                activeValue: 1,
                changes: {},
                defaultChanges: {},
                validateAfterReset: true,
            };
            expect(reducedForm).toEqual(result);
        });
    });
    describe(definition_1.FORM_DEFAULT_CHANGE_ACTION_TYPE, function () {
        it('test1', function () {
            var reducedForm = form_reducer_1.formReducer({
                changes: { param1: 1 },
                defaultChanges: { value1: 100, name: 'name1' },
                dirty: true,
            }, action_1.FormActionBuilder.buildDefaultChangesPlainAction(TEST_SECTION, { name: 'name2' }));
            var result = {
                changes: { param1: 1 },
                defaultChanges: { value1: 100, name: 'name2' },
                dirty: true,
            };
            expect(reducedForm).toEqual(result);
        });
        it('test2', function () {
            var reducedForm = form_reducer_1.formReducer({
                changes: {},
                defaultChanges: {},
            }, action_1.FormActionBuilder.buildDefaultChangesPlainAction(TEST_SECTION, { name: 'name2' }));
            var result = {
                changes: {},
                defaultChanges: { name: 'name2' },
                dirty: true,
            };
            expect(reducedForm).toEqual(result);
        });
    });
    describe(definition_1.FORM_CHANGE_ACTION_TYPE, function () {
        it('test1', function () {
            var reducedForm = form_reducer_1.formReducer({
                changes: { value1: 100 },
                defaultChanges: { name: 'name1' },
                dirty: true,
            }, action_1.FormActionBuilder.buildChangesPlainAction(TEST_SECTION, { name: 'name2' }));
            var result = {
                changes: { value1: 100, name: 'name2' },
                defaultChanges: { name: 'name1' },
                dirty: true,
                error: null,
                touched: true,
            };
            expect(reducedForm).toEqual(result);
        });
        it('test2', function () {
            var reducedForm = form_reducer_1.formReducer({
                changes: {},
                defaultChanges: {},
            }, action_1.FormActionBuilder.buildChangesPlainAction(TEST_SECTION, { name: 'name2' }));
            var result = {
                changes: { name: 'name2' },
                defaultChanges: {},
                dirty: true,
                error: null,
                touched: true,
            };
            expect(reducedForm).toEqual(result);
        });
    });
});
//# sourceMappingURL=form.reducer.spec.js.map