import { AnyT } from '../../../definitions.interface';
import { IGenericPdfPlugin, IPdfViewerPageEntity } from '../../../definition';
export declare class GenericPdfPlugin implements IGenericPdfPlugin {
    private workerSrc;
    private canvasResolver;
    private onFinish;
    private static readonly logger;
    private static readonly DEFAULT_VIEWPORT_SCALE;
    private readonly domAccessor;
    private autoScale;
    private initialScale;
    private loadedDocument;
    private loadPageTask;
    private loadTask;
    private onError?;
    private onStart;
    private page;
    private scale;
    private src;
    /**
     * @stable [23.03.2020]
     * @param {string} workerSrc
     * @param {() => HTMLCanvasElement} canvasResolver
     * @param {(callback: (page: IPdfViewerPageEntity) => void) => void} onFinish
     */
    constructor(workerSrc: string, canvasResolver: () => HTMLCanvasElement, onFinish: (callback: (page: IPdfViewerPageEntity) => void) => void);
    /**
     * @stable [23.03.2020]
     * @param {() => void} onStart
     * @returns {IGenericPdfPlugin}
     */
    setOnStart(onStart: () => void): IGenericPdfPlugin;
    /**
     * @stable [23.03.2020]
     * @param {(error: AnyT) => void} onError
     * @returns {IGenericPdfPlugin}
     */
    setOnError(onError: (error: AnyT) => void): IGenericPdfPlugin;
    /**
     * @stable [14.11.2018]
     * @param {number} page
     * @returns {IGenericPdfPlugin}
     */
    setPage(page: number): IGenericPdfPlugin;
    /**
     * @stable [14.11.2018]
     * @param {string} src
     * @returns {IGenericPdfPlugin}
     */
    setSrc(src: string): IGenericPdfPlugin;
    /**
     * @stable [14.11.2018]
     * @param {number} scale
     * @returns {IGenericPdfPlugin}
     */
    setScale(scale: number): IGenericPdfPlugin;
    /**
     * @stable [23.03.2020]
     * @param {boolean} autoScale
     * @returns {IGenericPdfPlugin}
     */
    setAutoScale(autoScale: boolean): IGenericPdfPlugin;
    /**
     * @stable [14.11.2018]
     */
    loadDocument(): void;
    /**
     * @stable [18.03.2020]
     */
    refreshPage(): void;
    /**
     * @stable [18.03.2020]
     * @returns {boolean}
     */
    get hasLoadedDocument(): boolean;
    /**
     * @stable [23.03.2020]
     * @returns {number}
     */
    get pagesCount(): number;
    /**
     * @stable [14.11.2018]
     */
    cancel(): void;
    /**
     * @stable [14.11.2018]
     * @param {IPdfViewerDocumentEntity} pdf
     * @returns {IPdfViewerDocumentEntity}
     */
    private onLoad;
    /**
     * @stable [14.11.2018]
     * @param {IPdfViewerPageEntity} page
     * @returns {IPdfViewerPageEntity}
     */
    private onLoadPage;
    /**
     * @stable [14.11.2018]
     * @param {AnyT} error
     * @returns {AnyT}
     */
    private onLoadError;
    /**
     * @stable [14.11.2018]
     */
    private cancelTask;
    /**
     * @stable [14.11.2018]
     */
    private cancelPageTask;
    /**
     * @stable [14.11.2018]
     * @returns {HTMLCanvasElement}
     */
    private get renderArea();
}
