/// <reference types="react" />
import { IViewerProps, IViewerState } from '../../definition';
import { AnyT } from '../../definitions.interface';
import { GenericComponent } from '../base/generic.component';
export declare abstract class Viewer<TProps extends IViewerProps = IViewerProps, TState extends IViewerState = IViewerState> extends GenericComponent<TProps, TState> {
    private static readonly DEFAULT_PAGE;
    private readonly previewDialogRef;
    /**
     * @stable [16.03.2020]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    componentDidUpdate(prevProps: TProps, prevState: TState): void;
    /**
     * @stable [16.03.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [02.10.2020]
     */
    render(): JSX.Element;
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    protected getPreviewExtraActionsElement(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    protected get previewForwardActionElement(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    protected get previewBackActionElement(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    protected get incrementScaleAction(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    protected get decrementScaleAction(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @param {AnyT} error
     */
    protected onLoadError(error: AnyT): void;
    /**
     * @stable [18.03.2020]
     * @param {(...args) => void} callback
     */
    protected onLoadSucceed(callback?: (...args: any[]) => void): void;
    /**
     * @stable [18.03.2020]
     */
    protected onLoadStart(): void;
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    protected isPreviewForwardActionDisabled(): boolean;
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    protected isPreviewBackActionDisabled(): boolean;
    /**
     * @stable [19.06.2020]
     * @returns {string}
     */
    protected getClassName(): string;
    /**
     * @stable [16.03.2020]
     */
    protected refreshOnSrcChanges(): void;
    /**
     * @stable [16.03.2020]
     */
    protected refreshOnInternalChanges(): void;
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    protected abstract getContentElement(): JSX.Element;
    /**
     * @stable [15.03.2020]
     * @returns {JSX.Element}
     */
    protected abstract gePreviewElement(): JSX.Element;
    /**
     * @stable [02.08.2020]
     */
    protected get inProgress(): boolean;
    /**
     * @stable [16.03.2020]
     */
    protected onDialogClose(): void;
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    protected hasInternalChanges(prevProps: TProps, prevState: TState): boolean;
    /**
     * @stable [15.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    protected hasScaleChanges(prevProps: TProps, prevState: TState): boolean;
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    protected hasSrcChanges(prevProps: TProps, prevState: TState): boolean;
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    protected hasPageChanges(prevProps: TProps, prevState: TState): boolean;
    /**
     * @stable [16.03.2020]
     */
    private onBack;
    /**
     * @stable [16.03.2020]
     */
    private onForward;
    /**
     * @stable [16.03.2020]
     */
    private onIncrementScale;
    /**
     * @stable [16.03.2020]
     */
    private onDecrementScale;
    /**
     * @stable [16.03.2020]
     */
    private showPreviewDialog;
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualOrDefaultPage(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualPage(): number;
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualOrDefaultPreviewPage(): number;
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualPreviewPage(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualOrDefaultPreviewScale(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualOrDefaultScale(): number;
    /**
     * @stable [18.03.2020]
     * @returns {string}
     */
    protected get actualSrc(): string;
    /**
     * @stable [23.03.2020]
     * @returns {number}
     */
    protected get defaultScaleDiff(): number;
    /**
     * @stable [23.03.2020]
     * @returns {number}
     */
    protected get defaultScale(): number;
    /**
     * @stable [19.06.2020]
     * @returns {React.ReactNode}
     */
    private get bodyElement();
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    private get previewDialogElement();
    /**
     * @stable [18.03.2020]
     * @returns {JSX.Element}
     */
    private get previewIconElement();
    /**
     * @stable [18.03.2020]
     * @returns {boolean}
     */
    private get isInfoRendered();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get canPreview();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get doesErrorExist();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get isActualSrcAbsent();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get isSrcAbsent();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get isDefaultSrcAbsent();
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    private get isPreviewUsed();
}
