"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SucceedFormMiddlewareFactories = exports.makeSucceedRelatedFormMiddleware = exports.makeSucceedFormMiddleware = void 0;
var util_1 = require("../../util");
var action_1 = require("../../action");
var action_builder_1 = require("../../component/action.builder");
var di_1 = require("../../di");
/**
 * @stable [11.04.2020]
 * @param {ISucceedFormMiddlewareConfigEntity} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedFormMiddleware = function (cfg) {
    cfg = cfg || {};
    var succeedText = cfg.succeedText;
    var actualFormSection = util_1.SectionUtils.asFormSection(cfg);
    return __spreadArrays((util_1.WrapperUtils.isNavigateBackNeeded(cfg) || !util_1.ObjectUtils.isObjectNotEmpty(actualFormSection)
        ? [action_1.RouterActionBuilder.buildBackAction()]
        : [action_1.FormActionBuilder.buildSubmitDoneAction(actualFormSection)]), (succeedText === false
        ? []
        : [
            action_1.NotificationActionBuilder.buildInfoAction(di_1.DiServices.translator()(succeedText || di_1.DiServices.settings().messages.DATA_HAS_BEEN_SAVED_SUCCESSFULLY))
        ]));
};
/**
 * @deprecated Use makeSucceedRelatedFormEntityMiddleware
 */
exports.makeSucceedRelatedFormMiddleware = function (config) {
    var formSection = config.formSection;
    var apiEntity = config.action.data;
    var parentEntity = config.getEntity(config.state);
    var relatedEntities = apiEntity.newEntity
        ? (config.getRelatedEntities(parentEntity) || []).concat(config.relatedEntity)
        : (config.getRelatedEntities(parentEntity) || []).map(function (anotherEntity) { return anotherEntity.id === config.relatedEntity.id ? config.relatedEntity : anotherEntity; });
    var changes = config.makeRelatedChanges(relatedEntities);
    var payloadWrapper = { payload: { id: parentEntity.id, changes: changes } };
    return __spreadArrays(util_1.ConditionUtils.ifNotNilThanValue(config.listSection, function (listSection) { return ([
        action_builder_1.ListActionBuilder.buildUpdateAction(listSection, payloadWrapper),
        config.navigateBack !== false
            ? action_1.RouterActionBuilder.buildBackAction()
            : action_1.FormActionBuilder.buildSubmitDoneAction(formSection)
    ]); }, []), [
        action_1.NotificationActionBuilder.buildInfoAction(di_1.DiServices.translator()(config.succeedText || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved))
    ]);
};
/**
 * @stable [10.09.2020]
 * @param cfg
 */
var makeSucceedEditedListMiddleware = function (cfg) {
    var action = cfg.action, path = cfg.path, succeedText = cfg.succeedText;
    var actualListSection = util_1.SectionUtils.asListSection(cfg);
    return __spreadArrays([
        action_builder_1.ListActionBuilder.buildMergeAction(actualListSection, di_1.DiServices.modifyEntityFactory().makeInstance(action))
    ], (util_1.WrapperUtils.isNavigateBackNeeded(cfg)
        ? [
            action_1.RouterActionBuilder.buildReplaceAction(path || util_1.RouteUtils.asRoutePath(di_1.DiServices.dynamicSections().get(util_1.NvlUtils.nvl(util_1.SectionUtils.asContainerSection(cfg), actualListSection))))
        ]
        : []), (succeedText === false
        ? []
        : [
            action_1.NotificationActionBuilder.buildInfoAction(di_1.DiServices.translator()(succeedText || di_1.DiServices.settings().messages.DATA_HAS_BEEN_SAVED_SUCCESSFULLY))
        ]));
};
/**
 * @stable [10.09.2020]
 */
var SucceedFormMiddlewareFactories = /** @class */ (function () {
    function SucceedFormMiddlewareFactories() {
    }
    SucceedFormMiddlewareFactories.succeedEditedListMiddleware = makeSucceedEditedListMiddleware;
    return SucceedFormMiddlewareFactories;
}());
exports.SucceedFormMiddlewareFactories = SucceedFormMiddlewareFactories;
//# sourceMappingURL=succeed-form.middleware.js.map