import { AnyAction, Reducer, ReducersMapObject } from 'redux';
import { IEffectsAction } from 'redux-effects-promise';
import { IEntityActionBuilder, IEntityReducerFactoryConfigEntity } from '../definition';
export declare type FilterT = (action: IEffectsAction) => boolean;
/**
 * @stable - 10.04.2018
 * @param {string} customSection
 * @returns {FilterT}
 */
export declare function reducerSectionFilter(customSection: string): FilterT;
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {FilterT} filterObject
 * @returns {Reducer<S>}
 */
export declare const filter: <S>(reducer: Reducer<S>, filterObject: FilterT) => Reducer<S>;
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {string} customSection
 * @returns {Reducer<S>}
 */
export declare const filterBySection: <S>(reducer: Reducer<S>, customSection: string) => Reducer<S>;
/**
 * @stable - 15.04.2018
 * @param {TReducersMap} reducersMap
 * @returns {Reducer<ReducersMapObject>}
 */
export declare const composeReducers: <TReducersMap extends {}>(reducersMap: TReducersMap) => Reducer<ReducersMapObject>;
/**
 * @deprecated Use makeEntityReducer
 * @param {string} updateActionType
 * @param {string} destroyActionType
 * @param {TPayload} initialState
 * @returns {(state: TPayload, action: AnyAction) => TPayload}
 */
export declare const entityReducerFactory: (updateActionType: string, destroyActionType: string, initialState?: any) => (state: {}, action: AnyAction) => {};
/**
 * @stable [06.04.2020]
 * @param {IEntityReducerFactoryConfigEntity} config
 * @returns {(state: {}, action: AnyAction) => {}}
 */
export declare const makeEntityReducer: (config: IEntityReducerFactoryConfigEntity) => (state: {}, action: AnyAction) => {};
/**
 * @stable [06.04.2020]
 * @param {IEntityReducerFactoryConfigEntity} config
 * @returns {IEntityActionBuilder<TValue>}
 */
export declare const makeEntityActionBuilderFactory: <TValue = {}>(config: IEntityReducerFactoryConfigEntity) => IEntityActionBuilder<TValue>;
