"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArrayUtils = exports.subArray = exports.isArrayNotEmpty = exports.arrayNextMinNegativeValue = exports.arrayMinValue = exports.makeArray = void 0;
var R = require("ramda");
var entity_1 = require("./entity");
var filter_1 = require("./filter");
var cond_1 = require("./cond");
var nvl_1 = require("./nvl");
var type_1 = require("./type");
/**
 * @stable [05.11.2020]
 * @param length
 */
exports.makeArray = function (length) { return Array.apply(null, { length: length }); };
/**
 * @stable [19.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayMinValue = function (array) { return R.reduce(R.min, Infinity, array); };
/**
 * @stable [22.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayNextMinNegativeValue = function (array) { return Math.min(Number(exports.arrayMinValue(array)), 0) - 1; };
/**
 * @stable [19.12.2018]
 * @param {TValue[]} array
 * @returns {boolean}
 */
exports.isArrayNotEmpty = function (array) { return Array.isArray(array) && !R.isEmpty(array); };
/**
 * @stable [28.01.2019]
 * @param {TValue[]} array
 * @param {number} limit
 * @returns {TValue[]}
 */
exports.subArray = function (array, limit) {
    return cond_1.ifNotNilThanValue(array, function () { return array.slice(0, Math.min(array.length, nvl_1.nvl(limit, array.length))); });
};
/**
 * @stable [06.09.2020]
 * @param array
 * @param item
 * @param predicate
 * @param itemFactory
 */
var mergeArrayItem = function (array, item, predicate, itemFactory) {
    if (predicate === void 0) { predicate = filter_1.FilterUtils.SAME_ENTITY_PREDICATE; }
    var $array = array || [];
    var hasEntity = doesArrayContainExistedEntity($array, item, predicate);
    var hasItemFactory = type_1.TypeUtils.isFn(itemFactory);
    var result = hasEntity
        ? $array
        : __spreadArrays([hasItemFactory ? itemFactory(item) : item], $array);
    if (!hasEntity) {
        return result;
    }
    return result.map(function ($item) { return predicate($item, item)
        ? (hasItemFactory
            ? itemFactory($item) // Custom creating
            : item // Replace
        )
        : $item; });
};
/**
 * @stable [31.07.2020]
 * @param data
 * @param entity
 * @param predicate
 */
var doesArrayContainEntity = function (data, entity, predicate) {
    if (predicate === void 0) { predicate = filter_1.FilterUtils.SAME_ENTITY_PREDICATE; }
    return R.any(function (item) { return predicate(item, entity); }, data || []);
};
/**
 * @stable [31.07.2020]
 * @param data
 * @param entity
 * @param predicate
 */
var doesArrayContainExistedEntity = function (data, entity, predicate) {
    if (predicate === void 0) { predicate = filter_1.FilterUtils.SAME_ENTITY_PREDICATE; }
    return !entity_1.EntityUtils.isNewEntity(entity) && doesArrayContainEntity(data, entity, predicate);
};
/**
 * @stable [31.07.2020]
 */
var ArrayUtils = /** @class */ (function () {
    function ArrayUtils() {
    }
    ArrayUtils.doesArrayContainExistedEntity = doesArrayContainExistedEntity;
    ArrayUtils.makeArray = exports.makeArray;
    ArrayUtils.mergeArrayItem = mergeArrayItem;
    return ArrayUtils;
}());
exports.ArrayUtils = ArrayUtils;
//# sourceMappingURL=array.js.map