import { IEffectsAction } from 'redux-effects-promise';
import { EntityIdT, IActiveValueWrapper, IChangesWrapper, IChannelWrapper, IDataWrapper, IDictionariesWrapper, IDirectionsWrapper, IDirtyWrapper, IElementWrapper, IEntity, IEntityIdTWrapper, IEntityWrapper, IErrorWrapper, IFilterWrapper, IFormWrapper, ILayoutWrapper, IListWrapper, INotificationWrapper, IPrimaryFilterWrapper, IProgressWrapper, IQueryFilterWrapper, IQueryWrapper, IQueueWrapper, IRawDataWrapper, ISecondaryFilterWrapper, ISectionNameWrapper, ISelectedWrapper, IStackWrapper, ITabPanelWrapper, ITokenWrapper, ITransportWrapper, IUserWrapper, IValidWrapper } from '../definitions.interface';
import { IReduxChannelEntity, IReduxChannelHolderEntity, IReduxChannelMessageEntity, IReduxChannelsEntity, IReduxFormHolderEntity, IReduxLayoutHolderEntity, IReduxListHolderEntity, IReduxQueryFilterHolderEntity, IReduxStackHolderEntity, IReduxStackItemEntity, LayoutModesEnum, ToolbarToolsEnum } from '../definition';
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectToken: <TValue = string>(wrapper: ITokenWrapper<TValue>) => TValue;
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectEntity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectData: <TData>(wrapper: IDataWrapper<TData>) => TData;
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectValid: (wrapper: IValidWrapper) => boolean;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectValidFromAction: (wrapper: IEffectsAction) => boolean;
/**
 * @stable [21.07.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [21.07.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
export declare const selectSelectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => EntityIdT;
/**
 * @stable [06.05.2020]
 */
export declare class Selectors {
    static readonly activeToolbarToolsFromDirtyWrapper: (wrapper: IDirtyWrapper) => ToolbarToolsEnum[];
    static readonly activeValue: <TValue>(wrapper: IActiveValueWrapper<TValue>) => TValue;
    static readonly changes: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
    static readonly channel: <TEntity>(wrapper: IChannelWrapper<TEntity>) => TEntity;
    static readonly channelEntity: <TEntity = IReduxChannelsEntity>(wrapper: IReduxChannelHolderEntity<TEntity>, ip: string) => IReduxChannelEntity;
    static readonly channelMessagesByIp: <TMessage = any, TEntity = IReduxChannelsEntity>(wrapper: IReduxChannelHolderEntity<TEntity>, ip: string) => IReduxChannelMessageEntity<TMessage>[];
    static readonly data: <TData>(wrapper: IDataWrapper<TData>) => TData;
    static readonly dictionaries: <TValue>(wrapper: IDictionariesWrapper<TValue>) => TValue;
    static readonly directions: <TValue>(wrapper: IDirectionsWrapper<TValue>) => TValue;
    static readonly element: <TValue = any>(wrapper: IElementWrapper<TValue>) => TValue;
    static readonly entity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
    static readonly entityId: (entity: IEntityIdTWrapper) => import("../definitions.interface").StringNumberT;
    static readonly error: <TValue = any>(entity: IErrorWrapper<TValue>) => TValue;
    static readonly filter: <TValue = string>(wrapper: IFilterWrapper<TValue>) => TValue;
    static readonly firstStackItemEntity: (entity: IReduxStackHolderEntity<import("../definition").IReduxStackEntity>) => IReduxStackItemEntity;
    static readonly form: <TValue>(wrapper: IFormWrapper<TValue>) => TValue;
    static readonly formHolderEntityChanges: <TEntity = IEntity>(entity: IReduxFormHolderEntity<TEntity>) => TEntity;
    static readonly layout: <TEntity>(wrapper: ILayoutWrapper<TEntity>) => TEntity;
    static readonly layoutMode: (entity: IReduxLayoutHolderEntity<import("../definition").IReduxLayoutEntity>) => LayoutModesEnum;
    static readonly list: <TValue>(wrapper: IListWrapper<TValue>) => TValue;
    static readonly listProgress: (entity: IReduxListHolderEntity<IEntity, any, import("../definition").IReduxListEntity<IEntity, any>>) => boolean;
    static readonly listRawData: <TRawData = any>(entity: IReduxListHolderEntity<IEntity, any, import("../definition").IReduxListEntity<IEntity, any>>) => TRawData;
    static readonly listSelectedEntity: <TEntity extends IEntity>(entity: IReduxListHolderEntity<TEntity, any, import("../definition").IReduxListEntity<TEntity, any>>) => TEntity;
    static readonly mergedLayoutMode: (merged: IReduxLayoutHolderEntity<import("../definition").IReduxLayoutEntity>, original: IReduxLayoutHolderEntity<import("../definition").IReduxLayoutEntity>) => LayoutModesEnum;
    static readonly notification: <TEntity>(wrapper: INotificationWrapper<TEntity>) => TEntity;
    static readonly payloadFromAction: <TPayload>(action: IEffectsAction) => TPayload;
    static readonly preventEffectsFromAction: (wrapper: IEffectsAction) => boolean;
    static readonly previousActionFromAction: (wrapper: IEffectsAction) => IEffectsAction;
    static readonly previousActionTypeFromAction: (action: IEffectsAction) => string;
    static readonly primaryFilter: <TValue>(wrapper: IPrimaryFilterWrapper<TValue>) => TValue;
    static readonly progress: (wrapper: IProgressWrapper<boolean>) => boolean;
    static readonly query: (wrapper: IQueryWrapper<string>) => string;
    static readonly queryFilter: <TValue = string>(wrapper: IQueryFilterWrapper<TValue>) => TValue;
    static readonly queryFilterEntityQuery: (entity: IReduxQueryFilterHolderEntity) => string;
    static readonly queue: <TValue>(wrapper: IQueueWrapper<TValue>) => TValue;
    static readonly rawData: <TValue = any>(wrapper: IRawDataWrapper<TValue>) => TValue;
    static readonly secondaryFilter: <TValue>(wrapper: ISecondaryFilterWrapper<TValue>) => TValue;
    static readonly sectionFromAction: (action: IEffectsAction) => string;
    static readonly sectionName: (wrapper: ISectionNameWrapper) => string;
    static readonly selected: <TEntity = IEntity>(entity: ISelectedWrapper<TEntity>) => TEntity;
    static readonly selectedEntityFromAction: <TEntity = IEntity>(action: IEffectsAction) => TEntity;
    static readonly selectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => import("../definitions.interface").StringNumberT;
    static readonly stack: <TEntity>(wrapper: IStackWrapper<TEntity>) => TEntity;
    static readonly stackItemEntities: (entity: IReduxStackHolderEntity<import("../definition").IReduxStackEntity>) => IReduxStackItemEntity[];
    static readonly tabPanel: <TTabPanel>(entity: ITabPanelWrapper<TTabPanel>) => TTabPanel;
    static readonly transport: <TTransport>(wrapper: ITransportWrapper<TTransport>) => TTransport;
    static readonly user: <TUser>(wrapper: IUserWrapper<TUser>) => TUser;
}
